=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-03-26 21:36:11 +0000
+++ drizzled/drizzled.cc	2010-04-05 16:06:01 +0000
@@ -49,6 +49,7 @@
 #include "drizzled/plugin/scheduler.h"
 #include "drizzled/plugin/xa_resource_manager.h"
 #include "drizzled/plugin/monitored_in_transaction.h"
+#include "drizzled/replication_services.h" /* For ReplicationServices::evaluateRegisteredPlugins() */
 #include "drizzled/probes.h"
 #include "drizzled/session_list.h"
 #include "drizzled/charset.h"
@@ -2299,6 +2300,20 @@
   if (init_server_components(plugins))
     unireg_abort(1);
 
+  /**
+   * This check must be done after init_server_components for now
+   * because we don't yet have plugin dependency tracking...
+   *
+   * ReplicationServices::evaluateRegisteredPlugins() will print error messages to stderr
+   * via errmsg_printf().
+   *
+   * @todo
+   *
+   * not checking return since unireg_abort() hangs
+   */
+  ReplicationServices &replication_services= ReplicationServices::singleton();
+  (void) replication_services.evaluateRegisteredPlugins();
+
   if (plugin::Listen::setup())
     unireg_abort(1);
 

=== modified file 'drizzled/plugin/transaction_applier.cc'
--- drizzled/plugin/transaction_applier.cc	2009-12-11 21:54:18 +0000
+++ drizzled/plugin/transaction_applier.cc	2010-04-05 16:06:01 +0000
@@ -27,18 +27,13 @@
 namespace drizzled
 {
 
-bool plugin::TransactionApplier::addPlugin(plugin::TransactionApplier *applier)
+bool plugin::TransactionApplier::addPlugin(plugin::TransactionApplier *)
 {
-  ReplicationServices &replication_services= ReplicationServices::singleton();
-  /** @TODO ReplicationServices should indicate error in some way here */
-  replication_services.attachApplier(applier);
   return false;
 }
 
-void plugin::TransactionApplier::removePlugin(plugin::TransactionApplier *applier)
+void plugin::TransactionApplier::removePlugin(plugin::TransactionApplier *)
 {
-  ReplicationServices &replication_services= ReplicationServices::singleton();
-  replication_services.detachApplier(applier);
 }
 
 } /* namespace drizzled */

=== modified file 'drizzled/plugin/transaction_applier.h'
--- drizzled/plugin/transaction_applier.h	2010-03-27 18:03:59 +0000
+++ drizzled/plugin/transaction_applier.h	2010-04-05 16:06:01 +0000
@@ -35,7 +35,6 @@
 
 #include "drizzled/plugin/plugin.h"
 #include "drizzled/plugin/replication.h"
-#include "drizzled/atomics.h"
 
 namespace drizzled
 {
@@ -55,12 +54,10 @@
   TransactionApplier();
   TransactionApplier(const TransactionApplier &);
   TransactionApplier& operator=(const TransactionApplier &);
-  atomic<bool> is_enabled;
 public:
   explicit TransactionApplier(std::string name_arg)
     : Plugin(name_arg, "TransactionApplier")
   {
-    is_enabled= true;
   }
   virtual ~TransactionApplier() {}
   /**
@@ -83,20 +80,6 @@
 
   static bool addPlugin(TransactionApplier *applier);
   static void removePlugin(TransactionApplier *applier);
-  virtual bool isEnabled() const
-  {
-    return is_enabled;
-  }
-
-  virtual void enable()
-  {
-    is_enabled= true;
-  }
-
-  virtual void disable()
-  {
-    is_enabled= false;
-  }
 };
 
 } /* namespace plugin */

=== modified file 'drizzled/plugin/transaction_replicator.cc'
--- drizzled/plugin/transaction_replicator.cc	2009-12-11 21:54:18 +0000
+++ drizzled/plugin/transaction_replicator.cc	2010-04-05 16:06:01 +0000
@@ -31,7 +31,6 @@
 bool plugin::TransactionReplicator::addPlugin(plugin::TransactionReplicator *replicator)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
-  /** @TODO ReplicationServices should indicate error in some way here */
   replication_services.attachReplicator(replicator);
   return false;
 }

=== modified file 'drizzled/plugin/transaction_replicator.h'
--- drizzled/plugin/transaction_replicator.h	2010-03-27 18:03:59 +0000
+++ drizzled/plugin/transaction_replicator.h	2010-04-05 16:06:01 +0000
@@ -25,7 +25,6 @@
 #ifndef DRIZZLED_PLUGIN_TRANSACTION_REPLICATOR_H
 #define DRIZZLED_PLUGIN_TRANSACTION_REPLICATOR_H
 
-#include "drizzled/atomics.h"
 #include "drizzled/plugin/replication.h"
 #include "drizzled/plugin/plugin.h"
 
@@ -61,12 +60,10 @@
   TransactionReplicator();
   TransactionReplicator(const TransactionReplicator &);
   TransactionReplicator& operator=(const TransactionReplicator &);
-  atomic<bool> is_enabled;
 public:
   explicit TransactionReplicator(std::string name_arg)
     : Plugin(name_arg, "TransactionReplicator")
   {
-    is_enabled= true;
   }
   virtual ~TransactionReplicator() {}
 
@@ -91,21 +88,6 @@
                                           message::Transaction &to_replicate)= 0;
   static bool addPlugin(TransactionReplicator *replicator);
   static void removePlugin(TransactionReplicator *replicator);
-
-  virtual bool isEnabled() const
-  {
-    return is_enabled;
-  }
-
-  virtual void enable()
-  {
-    is_enabled= true;
-  }
-
-  virtual void disable()
-  {
-    is_enabled= false;
-  }
 };
 
 } /* namespace plugin */

=== modified file 'drizzled/replication_services.cc'
--- drizzled/replication_services.cc	2010-04-02 15:07:29 +0000
+++ drizzled/replication_services.cc	2010-04-05 16:06:01 +0000
@@ -43,99 +43,120 @@
 #include "drizzled/session.h"
 #include "drizzled/error.h"
 
+#include <string>
 #include <vector>
+#include <algorithm>
 
 using namespace std;
 
 namespace drizzled
 {
 
-ReplicationServices::ReplicationServices()
+ReplicationServices::ReplicationServices() :
+  is_active(false)
 {
-  is_active= false;
 }
 
-void ReplicationServices::evaluateActivePlugins()
+void ReplicationServices::normalizeReplicatorName(string &name)
 {
-  /* 
-   * We loop through replicators and appliers, evaluating
-   * whether or not there is at least one active replicator
-   * and one active applier.  If not, we set is_active
-   * to false.
-   */
-  bool tmp_is_active= false;
-
-  if (replicators.empty() || appliers.empty())
-  {
-    is_active= false;
-    return;
-  }
-
-  /* 
-   * Determine if any remaining replicators and if those
-   * replicators are active...if not, set is_active
-   * to false
-   */
-  for (Replicators::iterator repl_iter= replicators.begin();
-       repl_iter != replicators.end();
-       ++repl_iter)
-  {
-    if ((*repl_iter)->isEnabled())
+  transform(name.begin(),
+            name.end(),
+            name.begin(),
+            ::tolower);
+  if (name.find("replicator") == string::npos)
+    name.append("replicator", 10);
+  {
+    size_t found_underscore= name.find('_');
+    while (found_underscore != string::npos)
     {
-      tmp_is_active= true;
-      break;
+      name.erase(found_underscore, 1);
+      found_underscore= name.find('_');
     }
   }
-  if (! tmp_is_active)
-  {
-    /* No active replicators. Set is_active to false and exit. */
-    is_active= false;
-    return;
-  }
+}
 
+bool ReplicationServices::evaluateRegisteredPlugins()
+{
   /* 
-   * OK, we know there's at least one active replicator.
-   *
-   * Now determine if any remaining replicators and if those
-   * replicators are active...if not, set is_active
-   * to false
+   * We loop through appliers that have registered with us
+   * and attempts to pair the applier with its requested
+   * replicator.  If an applier has requested a replicator
+   * that has either not been built or has not registered
+   * with the replication services, we print an error and
+   * return false
    */
+  if (appliers.empty())
+    return true;
+
+  if (replicators.empty() && not appliers.empty())
+  {
+    errmsg_printf(ERRMSG_LVL_ERROR,
+                  N_("You registered a TransactionApplier plugin but no "
+                     "TransactionReplicator plugins were registered.\n"));
+    return false;
+  }
+
   for (Appliers::iterator appl_iter= appliers.begin();
        appl_iter != appliers.end();
        ++appl_iter)
   {
-    if ((*appl_iter)->isEnabled())
-    {
-      is_active= true;
-      return;
+    plugin::TransactionApplier *applier= (*appl_iter).second;
+    string requested_replicator_name= (*appl_iter).first;
+    normalizeReplicatorName(requested_replicator_name);
+
+    bool found= false;
+    Replicators::iterator repl_iter;
+    for (repl_iter= replicators.begin();
+         repl_iter != replicators.end();
+         ++repl_iter)
+    {
+      string replicator_name= (*repl_iter)->getName();
+      normalizeReplicatorName(replicator_name);
+
+      if (requested_replicator_name.compare(replicator_name) == 0)
+      {
+        found= true;
+        break;
+      }
+    }
+    if (not found)
+    {
+      errmsg_printf(ERRMSG_LVL_ERROR,
+                    N_("You registered a TransactionApplier plugin but no "
+                       "TransactionReplicator plugins were registered that match the "
+                       "requested replicator name of '%s'.\n"
+                       "We have deactivated the TransactionApplier '%s'.\n"),
+                       requested_replicator_name.c_str(),
+                       applier->getName().c_str());
+      applier->deactivate();
+      return false;
+    }
+    else
+    {
+      replication_streams.push_back(make_pair(*repl_iter, applier));
     }
   }
-  /* If we get here, there are no active appliers */
-  is_active= false;
+  is_active= true;
+  return true;
 }
 
 void ReplicationServices::attachReplicator(plugin::TransactionReplicator *in_replicator)
 {
   replicators.push_back(in_replicator);
-  evaluateActivePlugins();
 }
 
 void ReplicationServices::detachReplicator(plugin::TransactionReplicator *in_replicator)
 {
   replicators.erase(std::find(replicators.begin(), replicators.end(), in_replicator));
-  evaluateActivePlugins();
-}
-
-void ReplicationServices::attachApplier(plugin::TransactionApplier *in_applier)
-{
-  appliers.push_back(in_applier);
-  evaluateActivePlugins();
-}
-
-void ReplicationServices::detachApplier(plugin::TransactionApplier *in_applier)
-{
-  appliers.erase(std::find(appliers.begin(), appliers.end(), in_applier));
-  evaluateActivePlugins();
+}
+
+void ReplicationServices::attachApplier(plugin::TransactionApplier *in_applier, const string &requested_replicator_name)
+{
+  appliers.push_back(make_pair(requested_replicator_name, in_applier));
+}
+
+void ReplicationServices::detachApplier(plugin::TransactionApplier *)
+{
 }
 
 bool ReplicationServices::isActive() const
@@ -146,54 +167,36 @@
 plugin::ReplicationReturnCode ReplicationServices::pushTransactionMessage(Session &in_session,
                                                                           message::Transaction &to_push)
 {
-  vector<plugin::TransactionReplicator *>::iterator repl_iter= replicators.begin();
-  vector<plugin::TransactionApplier *>::iterator appl_start_iter, appl_iter;
-  appl_start_iter= appliers.begin();
-
-  plugin::TransactionReplicator *cur_repl;
-  plugin::TransactionApplier *cur_appl;
-
   plugin::ReplicationReturnCode result= plugin::SUCCESS;
 
-  while (repl_iter != replicators.end())
+  for (ReplicationStreams::iterator iter= replication_streams.begin();
+       iter != replication_streams.end();
+       ++iter)
   {
-    cur_repl= *repl_iter;
-    if (! cur_repl->isEnabled())
-    {
-      ++repl_iter;
-      continue;
-    }
-    
-    appl_iter= appl_start_iter;
-    while (appl_iter != appliers.end())
-    {
-      cur_appl= *appl_iter;
-
-      if (! cur_appl->isEnabled())
-      {
-        ++appl_iter;
-        continue;
-      }
-
-      result= cur_repl->replicate(cur_appl, in_session, to_push);
-
-      if (result == plugin::SUCCESS)
-      {
-        /* 
-         * We update the timestamp for the last applied Transaction so that
-         * publisher plugins can ask the replication services when the
-         * last known applied Transaction was using the getLastAppliedTimestamp()
-         * method.
-         */
-        last_applied_timestamp.fetch_and_store(to_push.transaction_context().end_timestamp());
-        ++appl_iter;
-      }
-      else
-        return result;
-    }
-    ++repl_iter;
+    plugin::TransactionReplicator *cur_repl= (*iter).first;
+    plugin::TransactionApplier *cur_appl= (*iter).second;
+
+    result= cur_repl->replicate(cur_appl, in_session, to_push);
+
+    if (result == plugin::SUCCESS)
+    {
+      /* 
+       * We update the timestamp for the last applied Transaction so that
+       * publisher plugins can ask the replication services when the
+       * last known applied Transaction was using the getLastAppliedTimestamp()
+       * method.
+       */
+      last_applied_timestamp.fetch_and_store(to_push.transaction_context().end_timestamp());
+    }
+    else
+      return result;
   }
   return result;
 }
 
+ReplicationServices::ReplicationStreams &ReplicationServices::getReplicationStreams()
+{
+  return replication_streams;
+}
+
 } /* namespace drizzled */

=== modified file 'drizzled/replication_services.h'
--- drizzled/replication_services.h	2010-03-26 17:38:50 +0000
+++ drizzled/replication_services.h	2010-04-05 16:06:01 +0000
@@ -28,7 +28,9 @@
 #include "drizzled/atomics.h"
 #include "drizzled/plugin/replication.h"
 
+#include <string>
 #include <vector>
+#include <utility>
 
 namespace drizzled
 {
@@ -67,32 +69,21 @@
     TRANSACTION= 1, /* A GPB Transaction Message */
     BLOB= 2 /* A BLOB value */
   };
-  typedef std::vector<plugin::TransactionReplicator *> Replicators;
-  typedef std::vector<plugin::TransactionApplier *> Appliers;
-private:
-  /** 
-   * Atomic boolean set to true if any *active* replicators
-   * or appliers are actually registered.
-   */
-  atomic<bool> is_active;
-  /**
-   * The timestamp of the last time a Transaction message was successfully
-   * applied (sent to an Applier)
-   */
-  atomic<uint64_t> last_applied_timestamp;
-  /** Our collection of replicator plugins */
-  Replicators replicators;
-  /** Our collection of applier plugins */
-  Appliers appliers;
-  /**
-   * Helper method which is called after any change in the
-   * registered appliers or replicators to evaluate whether
-   * any remaining plugins are actually active.
-   * 
-   * This method properly sets the is_active member variable.
-   */
-  void evaluateActivePlugins();
-public:
+  typedef std::pair<plugin::TransactionReplicator *, plugin::TransactionApplier *> ReplicationPair;
+  typedef std::vector<ReplicationPair> ReplicationStreams;
+  /**
+   * Method which is called after plugins have been loaded but
+   * before the first client connects.  It determines if the registration
+   * of applier and replicator plugins is proper and pairs
+   * the applier and requested replicator plugins into the replication
+   * streams.
+   *
+   * @todo
+   *
+   * This is only necessary because we don't yet have plugin dependency
+   * tracking...
+   */
+  bool evaluateRegisteredPlugins();
   /** 
    * Helper method which pushes a constructed message out to the registered
    * replicator and applier plugins.
@@ -123,6 +114,12 @@
    * a replicator and an applier that are *active*?
    */
   bool isActive() const;
+
+  /**
+   * Returns the list of replication streams
+   */
+  ReplicationStreams &getReplicationStreams();
+
   /**
    * Attaches a replicator to our internal collection of
    * replicators.
@@ -130,6 +127,7 @@
    * @param Pointer to a replicator to attach/register
    */
   void attachReplicator(plugin::TransactionReplicator *in_replicator);
+  
   /**
    * Detaches/unregisters a replicator with our internal
    * collection of replicators.
@@ -137,13 +135,16 @@
    * @param Pointer to the replicator to detach
    */
   void detachReplicator(plugin::TransactionReplicator *in_replicator);
+  
   /**
    * Attaches a applier to our internal collection of
    * appliers.
    *
    * @param Pointer to a applier to attach/register
+   * @param The name of the replicator to pair with
    */
-  void attachApplier(plugin::TransactionApplier *in_applier);
+  void attachApplier(plugin::TransactionApplier *in_applier, const std::string &requested_replicator);
+  
   /**
    * Detaches/unregisters a applier with our internal
    * collection of appliers.
@@ -151,10 +152,36 @@
    * @param Pointer to the applier to detach
    */
   void detachApplier(plugin::TransactionApplier *in_applier);
-  /** Returns the timestamp of the last Transaction which was sent to an
+
+  /** 
+   * Returns the timestamp of the last Transaction which was sent to an
    * applier.
    */
   uint64_t getLastAppliedTimestamp() const;
+private:
+  typedef std::vector<plugin::TransactionReplicator *> Replicators;
+  typedef std::vector<std::pair<std::string, plugin::TransactionApplier *> > Appliers;
+  /** 
+   * Atomic boolean set to true if any *active* replicators
+   * or appliers are actually registered.
+   */
+  bool is_active;
+  /**
+   * The timestamp of the last time a Transaction message was successfully
+   * applied (sent to an Applier)
+   */
+  atomic<uint64_t> last_applied_timestamp;
+  /** Our collection of registered replicator plugins */
+  Replicators replicators;
+  /** Our collection of registered applier plugins and their requested replicator plugin names */
+  Appliers appliers;
+  /** Our replication streams */
+  ReplicationStreams replication_streams;
+  /**
+   * Strips underscores and lowercases supplied replicator name
+   * or requested name, and appends the suffix "replicator" if missing...
+   */
+  void normalizeReplicatorName(std::string &name);
 };
 
 } /* namespace drizzled */

=== modified file 'plugin/default_replicator/default_replicator.cc'
--- plugin/default_replicator/default_replicator.cc	2010-03-27 18:03:59 +0000
+++ plugin/default_replicator/default_replicator.cc	2010-04-05 16:06:01 +0000
@@ -45,23 +45,6 @@
 using namespace std;
 using namespace drizzled;
 
-static bool sysvar_default_replicator_enable= false;
-
-bool DefaultReplicator::isEnabled() const
-{
-  return sysvar_default_replicator_enable;
-}
-
-void DefaultReplicator::enable()
-{
-  sysvar_default_replicator_enable= true;
-}
-
-void DefaultReplicator::disable()
-{
-  sysvar_default_replicator_enable= false;
-}
-
 plugin::ReplicationReturnCode
 DefaultReplicator::replicate(plugin::TransactionApplier *in_applier,
                              Session &in_session,
@@ -83,30 +66,4 @@
   return 0;
 }
 
-static DRIZZLE_SYSVAR_BOOL(
-  enable,
-  sysvar_default_replicator_enable,
-  PLUGIN_VAR_NOCMDARG,
-  N_("Enable default replicator"),
-  NULL, /* check func */
-  NULL, /* update func */
-  false /* default */);
-
-static drizzle_sys_var* default_replicator_system_variables[]= {
-  DRIZZLE_SYSVAR(enable),
-  NULL
-};
-
-DRIZZLE_DECLARE_PLUGIN
-{
-  DRIZZLE_VERSION_ID,
-  "default_replicator",
-  "0.1",
-  "Jay Pipes",
-  N_("Default Replicator"),
-  PLUGIN_LICENSE_GPL,
-  init, /* Plugin Init */
-  default_replicator_system_variables, /* system variables */
-  NULL    /* config options */
-}
-DRIZZLE_DECLARE_PLUGIN_END;
+DRIZZLE_PLUGIN(init,  NULL);

=== modified file 'plugin/default_replicator/default_replicator.h'
--- plugin/default_replicator/default_replicator.h	2010-03-27 18:03:59 +0000
+++ plugin/default_replicator/default_replicator.h	2010-04-05 16:06:01 +0000
@@ -46,14 +46,6 @@
   ~DefaultReplicator() {}
 
   /**
-   * Returns whether the replicator is active
-   */
-  virtual bool isEnabled() const;
-
-  virtual void enable();
-  virtual void disable();
-
-  /**
    * Replicate a Transaction message to an Applier.
    *
    * @note

=== modified file 'plugin/filtered_replicator/filtered_replicator.cc'
--- plugin/filtered_replicator/filtered_replicator.cc	2010-03-27 18:03:59 +0000
+++ plugin/filtered_replicator/filtered_replicator.cc	2010-04-05 16:06:01 +0000
@@ -50,7 +50,6 @@
 using namespace std;
 using namespace drizzled;
 
-static bool sysvar_filtered_replicator_enabled= false;
 static char *sysvar_filtered_replicator_sch_filters= NULL;
 static char *sysvar_filtered_replicator_tab_filters= NULL;
 static char *sysvar_filtered_replicator_sch_regex= NULL;
@@ -126,11 +125,6 @@
   pthread_mutex_init(&sysvar_tab_lock, NULL);
 }
 
-bool FilteredReplicator::isEnabled() const
-{
-  return sysvar_filtered_replicator_enabled;
-}
-
 void FilteredReplicator::parseStatementTableMetadata(const message::Statement &in_statement,
                                                      string &in_schema_name,
                                                      string &in_table_name) const
@@ -204,15 +198,6 @@
     }
   }  
 }
-void FilteredReplicator::enable()
-{
-  sysvar_filtered_replicator_enabled= true;
-}
-
-void FilteredReplicator::disable()
-{
-  sysvar_filtered_replicator_enabled= false;
-}
 
 plugin::ReplicationReturnCode
 FilteredReplicator::replicate(plugin::TransactionApplier *in_applier,
@@ -511,18 +496,15 @@
 
 static int init(plugin::Context &context)
 {
-  if (sysvar_filtered_replicator_enabled)
+  filtered_replicator= new(std::nothrow) 
+    FilteredReplicator("filtered_replicator",
+                       sysvar_filtered_replicator_sch_filters,
+                       sysvar_filtered_replicator_tab_filters);
+  if (filtered_replicator == NULL)
   {
-    filtered_replicator= new(std::nothrow) 
-      FilteredReplicator("filtered_replicator",
-                         sysvar_filtered_replicator_sch_filters,
-                         sysvar_filtered_replicator_tab_filters);
-    if (filtered_replicator == NULL)
-    {
-      return 1;
-    }
-    context.add(filtered_replicator);
+    return 1;
   }
+  context.add(filtered_replicator);
   return 0;
 }
 
@@ -592,13 +574,6 @@
   }
 }
 
-static DRIZZLE_SYSVAR_BOOL(enable,
-                           sysvar_filtered_replicator_enabled,
-                           PLUGIN_VAR_NOCMDARG,
-                           N_("Enable filtered replicator"),
-                           NULL, /* check func */
-                           NULL, /* update func */
-                           false /*default */);
 static DRIZZLE_SYSVAR_STR(filteredschemas,
                           sysvar_filtered_replicator_sch_filters,
                           PLUGIN_VAR_OPCMDARG,
@@ -629,7 +604,6 @@
                           NULL);
 
 static drizzle_sys_var* filtered_replicator_system_variables[]= {
-  DRIZZLE_SYSVAR(enable),
   DRIZZLE_SYSVAR(filteredschemas),
   DRIZZLE_SYSVAR(filteredtables),
   DRIZZLE_SYSVAR(schemaregex),
@@ -637,16 +611,4 @@
   NULL
 };
 
-DRIZZLE_DECLARE_PLUGIN
-{
-  DRIZZLE_VERSION_ID,
-  "filtered_replicator",
-  "0.2",
-  "Padraig O'Sullivan",
-  N_("Filtered Replicator"),
-  PLUGIN_LICENSE_GPL,
-  init, /* Plugin Init */
-  filtered_replicator_system_variables, /* system variables */
-  NULL    /* config options */
-}
-DRIZZLE_DECLARE_PLUGIN_END;
+DRIZZLE_PLUGIN(init, filtered_replicator_system_variables);

=== modified file 'plugin/filtered_replicator/filtered_replicator.h'
--- plugin/filtered_replicator/filtered_replicator.h	2010-03-27 18:03:59 +0000
+++ plugin/filtered_replicator/filtered_replicator.h	2010-04-05 16:06:01 +0000
@@ -64,14 +64,6 @@
   }
 
   /**
-   * Returns whether the replicator is active
-   */
-  virtual bool isEnabled() const;
-
-  virtual void enable();
-  virtual void disable();
-
-  /**
    * Replicate a Transaction message to an Applier.
    *
    * @note

=== modified file 'plugin/filtered_replicator/plugin.ini'
--- plugin/filtered_replicator/plugin.ini	2009-11-29 18:30:06 +0000
+++ plugin/filtered_replicator/plugin.ini	2010-04-05 16:06:01 +0000
@@ -1,7 +1,9 @@
 [plugin]
 title=Filtered Replicator
-description=A simple filtered replicator which allows a user to filter out
-            events based on a schema or table name
+author=Padraig O Sullivan
+version=0.2
+license=PLUGIN_LICENSE_GPL
+description=A simple filtered replicator which allows a user to filter out events based on a schema or table name
 load_by_default=yes
 sources=filtered_replicator.cc
 headers=filtered_replicator.h

=== added directory 'plugin/replication_dictionary'
=== added file 'plugin/replication_dictionary/module.cc'
--- plugin/replication_dictionary/module.cc	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/module.cc	2010-04-05 16:06:01 +0000
@@ -0,0 +1,56 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2010 Jay Pipes <jaypipes@gmail.com>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Drizzle nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include "config.h"
+#include "streams.h"
+
+using namespace std;
+using namespace drizzled;
+
+static ReplicationStreamsTool *streams_tool;
+
+static int init(plugin::Context &context)
+{
+  streams_tool= new (nothrow) ReplicationStreamsTool;
+
+  if (streams_tool != NULL)
+  {
+    context.add(streams_tool);
+    return 0;
+  }
+  else
+  {
+    // error?
+    return 1;
+  }
+}
+
+DRIZZLE_PLUGIN(init, NULL);

=== added file 'plugin/replication_dictionary/plugin.ini'
--- plugin/replication_dictionary/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/plugin.ini	2010-04-05 16:06:01 +0000
@@ -0,0 +1,11 @@
+[plugin]
+title=Registry Dictionary
+author=Jay Pipes <jaypipes@gmail.com>
+license=PLUGIN_LICENSE_BSD
+description=Provides dictionary tables for replication system
+load_by_default=yes
+sources=
+  module.cc
+  streams.cc
+headers=
+  streams.h

=== added file 'plugin/replication_dictionary/streams.cc'
--- plugin/replication_dictionary/streams.cc	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/streams.cc	2010-04-05 16:06:01 +0000
@@ -0,0 +1,76 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2010 Jay Pipes <jaypipes@gmail.com>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Drizzle nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#include "config.h"
+#include "streams.h"
+
+#include <drizzled/plugin/transaction_replicator.h>
+#include <drizzled/plugin/transaction_applier.h>
+
+using namespace std;
+using namespace drizzled;
+
+ReplicationStreamsTool::ReplicationStreamsTool() :
+  plugin::TableFunction("DATA_DICTIONARY", "REPLICATION_STREAMS")
+{
+  add_field("REPLICATOR");
+  add_field("APPLIER");
+}
+
+ReplicationStreamsTool::Generator::Generator(Field **arg) :
+  plugin::TableFunction::Generator(arg)
+{
+  ReplicationServices &replication_services= ReplicationServices::singleton();
+  ReplicationServices::ReplicationStreams &replication_streams=
+    replication_services.getReplicationStreams();
+
+  it= replication_streams.begin();
+  end= replication_streams.end();
+}
+
+bool ReplicationStreamsTool::Generator::populate()
+{
+  if (it == end)
+    return false;
+
+  plugin::TransactionReplicator *replicator= (*it).first;
+  plugin::TransactionApplier *applier= (*it).second;
+
+  /* REPLICATOR */
+  push(replicator->getName());
+
+  /* APPLIER */
+  push(applier->getName());
+
+  ++it;
+
+  return true;
+}

=== added file 'plugin/replication_dictionary/streams.h'
--- plugin/replication_dictionary/streams.h	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/streams.h	2010-04-05 16:06:01 +0000
@@ -0,0 +1,60 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ * Copyright (c) 2010 Jay Pipes <jaypipes@gmail.com>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright notice,
+ *     this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above copyright notice,
+ *     this list of conditions and the following disclaimer in the documentation
+ *     and/or other materials provided with the distribution.
+ *   * Neither the name of Drizzle nor the names of its contributors
+ *     may be used to endorse or promote products derived from this software
+ *     without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ * THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef PLUGIN_REPLICATION_DICTIONARY_STREAMS_H
+#define PLUGIN_REPLICATION_DICTIONARY_STREAMS_H
+
+#include <drizzled/plugin/table_function.h>
+#include <drizzled/replication_services.h>
+
+class ReplicationStreamsTool : public drizzled::plugin::TableFunction
+{
+public:
+  ReplicationStreamsTool();
+
+  class Generator : public drizzled::plugin::TableFunction::Generator 
+  {
+    drizzled::ReplicationServices::ReplicationStreams::iterator it;
+    drizzled::ReplicationServices::ReplicationStreams::iterator end;
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+};
+
+#endif /* PLUGIN_REPLICATION_DICTIONARY_STREAMS_H */

=== added directory 'plugin/replication_dictionary/tests'
=== added directory 'plugin/replication_dictionary/tests/r'
=== added file 'plugin/replication_dictionary/tests/r/data_dictionary.result'
--- plugin/replication_dictionary/tests/r/data_dictionary.result	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/tests/r/data_dictionary.result	2010-04-05 16:06:01 +0000
@@ -0,0 +1,26 @@
+use data_dictionary;
+SELECT count(*) FROM plugins;
+count(*)
+#
+SELECT count(*) FROM modules;
+count(*)
+#
+show create table MODULES ;
+Table	Create Table
+MODULES	CREATE TABLE `modules` (
+  `MODULE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `MODULE_VERSION` varchar(20) NOT NULL DEFAULT '',
+  `MODULE_AUTHOR` varchar(64) NOT NULL DEFAULT '',
+  `IS_BUILTIN` varchar(5) NOT NULL DEFAULT '',
+  `MODULE_LIBRARY` varchar(254) NOT NULL DEFAULT '',
+  `MODULE_DESCRIPTION` varchar(254) NOT NULL DEFAULT '',
+  `MODULE_LICENSE` varchar(80) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+show create table PLUGINS ;
+Table	Create Table
+PLUGINS	CREATE TABLE `plugins` (
+  `PLUGIN_NAME` varchar(64) NOT NULL DEFAULT '',
+  `PLUGIN_TYPE` varchar(64) NOT NULL DEFAULT '',
+  `IS_ACTIVE` varchar(5) NOT NULL DEFAULT '',
+  `MODULE_NAME` varchar(64) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine

=== added file 'plugin/replication_dictionary/tests/r/replication_streams.result'
--- plugin/replication_dictionary/tests/r/replication_streams.result	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/tests/r/replication_streams.result	2010-04-05 16:06:01 +0000
@@ -0,0 +1,4 @@
+use data_dictionary;
+SELECT count(*) FROM data_dictionary.plugins;
+count(*)
+#

=== added file 'plugin/replication_dictionary/tests/r/slap.result'
--- plugin/replication_dictionary/tests/r/slap.result	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/tests/r/slap.result	2010-04-05 16:06:01 +0000
@@ -0,0 +1,2 @@
+CREATE SCHEMA drizzleslap;
+DROP SCHEMA drizzleslap;

=== added directory 'plugin/replication_dictionary/tests/t'
=== added file 'plugin/replication_dictionary/tests/t/data_dictionary.test'
--- plugin/replication_dictionary/tests/t/data_dictionary.test	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/tests/t/data_dictionary.test	2010-04-05 16:06:01 +0000
@@ -0,0 +1,8 @@
+# Drizzle's replication dictionary.
+
+use data_dictionary;
+
+--replace_column 1 #
+SELECT count(*) FROM replication_streams;
+
+show create table replication_streams;

=== added file 'plugin/replication_dictionary/tests/t/replication_streams-master.opt'
--- plugin/replication_dictionary/tests/t/replication_streams-master.opt	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/tests/t/replication_streams-master.opt	2010-04-05 16:06:01 +0000
@@ -0,0 +1,1 @@
+--transaction-log-enable --transaction-log-use-replicator=filtered

=== added file 'plugin/replication_dictionary/tests/t/replication_streams.test'
--- plugin/replication_dictionary/tests/t/replication_streams.test	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/tests/t/replication_streams.test	2010-04-05 16:06:01 +0000
@@ -0,0 +1,5 @@
+# Drizzle's replication dictionary's replication_streams table.
+
+use data_dictionary;
+
+SELECT * FROM data_dictionary.replication_streams;

=== added file 'plugin/replication_dictionary/tests/t/slap.test'
--- plugin/replication_dictionary/tests/t/slap.test	1970-01-01 00:00:00 +0000
+++ plugin/replication_dictionary/tests/t/slap.test	2010-04-05 16:06:01 +0000
@@ -0,0 +1,7 @@
+# Slap tests for concurrency
+CREATE SCHEMA drizzleslap;
+
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from data_dictionary.plugins" --delimiter=";"
+--exec $DRIZZLE_SLAP --silent  --concurrency=5 --iterations=20  --query="select * from data_dictionary.modules" --delimiter=";"
+
+DROP SCHEMA drizzleslap;

=== modified file 'plugin/transaction_log/module.cc'
--- plugin/transaction_log/module.cc	2010-03-27 18:51:59 +0000
+++ plugin/transaction_log/module.cc	2010-04-05 16:06:01 +0000
@@ -85,6 +85,12 @@
  * for managing write buffers
  */
 static uint32_t sysvar_transaction_log_num_write_buffers= 8;
+/**
+ * Transaction Log plugin system variable - The name of the replicator plugin
+ * to pair the transaction log's applier with.  Defaults to "default"
+ */
+static char *sysvar_transaction_log_use_replicator= NULL;
+static const char DEFAULT_USE_REPLICATOR[]= "default";
 
 /** DATA_DICTIONARY views */
 static TransactionLogTool *transaction_log_tool;
@@ -138,6 +144,9 @@
       return 1;
     }
     context.add(transaction_log_applier);
+    ReplicationServices &replication_services= ReplicationServices::singleton();
+    string replicator_name(sysvar_transaction_log_use_replicator);
+    replication_services.attachApplier(transaction_log_applier, replicator_name);
 
     /* Setup DATA_DICTIONARY views */
 
@@ -230,6 +239,14 @@
                           NULL, /* update func*/
                           DEFAULT_LOG_FILE_PATH /* default */);
 
+static DRIZZLE_SYSVAR_STR(use_replicator,
+                          sysvar_transaction_log_use_replicator,
+                          PLUGIN_VAR_READONLY,
+                          N_("Name of the replicator plugin to use (default='default_replicator')"),
+                          NULL, /* check func */
+                          NULL, /* update func*/
+                          DEFAULT_USE_REPLICATOR /* default */);
+
 static DRIZZLE_SYSVAR_BOOL(enable_checksum,
                            sysvar_transaction_log_checksum_enabled,
                            PLUGIN_VAR_NOCMDARG,
@@ -269,6 +286,7 @@
   DRIZZLE_SYSVAR(enable_checksum),
   DRIZZLE_SYSVAR(sync_method),
   DRIZZLE_SYSVAR(num_write_buffers),
+  DRIZZLE_SYSVAR(use_replicator),
   NULL
 };
 

=== added file 'plugin/transaction_log/tests/r/bad_replicator.result'
--- plugin/transaction_log/tests/r/bad_replicator.result	1970-01-01 00:00:00 +0000
+++ plugin/transaction_log/tests/r/bad_replicator.result	2010-04-05 16:06:01 +0000
@@ -0,0 +1,6 @@
+SET GLOBAL transaction_log_truncate_debug= true;
+SELECT * FROM DATA_DICTIONARY.PLUGINS
+WHERE DATA_DICTIONARY.PLUGINS.PLUGIN_NAME LIKE 'Transaction%';
+PLUGIN_NAME	PLUGIN_TYPE	IS_ACTIVE	MODULE_NAME
+transaction_log_applier	TransactionApplier	FALSE	transaction_log
+SET GLOBAL transaction_log_truncate_debug= true;

=== modified file 'plugin/transaction_log/tests/r/variables.result'
--- plugin/transaction_log/tests/r/variables.result	2010-03-27 18:51:59 +0000
+++ plugin/transaction_log/tests/r/variables.result	2010-04-05 16:06:01 +0000
@@ -7,3 +7,4 @@
 transaction_log_num_write_buffers	8
 transaction_log_sync_method	1
 transaction_log_truncate_debug	OFF
+transaction_log_use_replicator	default

=== modified file 'plugin/transaction_log/tests/t/alter-master.opt'
--- plugin/transaction_log/tests/t/alter-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/alter-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/auto_commit-master.opt'
--- plugin/transaction_log/tests/t/auto_commit-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/auto_commit-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== added file 'plugin/transaction_log/tests/t/bad_replicator-master.opt'
--- plugin/transaction_log/tests/t/bad_replicator-master.opt	1970-01-01 00:00:00 +0000
+++ plugin/transaction_log/tests/t/bad_replicator-master.opt	2010-04-05 16:06:01 +0000
@@ -0,0 +1,1 @@
+--transaction-log-enable --transaction-log-use-replicator=bad --scheduler=multi_thread

=== added file 'plugin/transaction_log/tests/t/bad_replicator.test'
--- plugin/transaction_log/tests/t/bad_replicator.test	1970-01-01 00:00:00 +0000
+++ plugin/transaction_log/tests/t/bad_replicator.test	2010-04-05 16:06:01 +0000
@@ -0,0 +1,16 @@
+#
+# Tests that an error occurs on startup for a bad replicator
+# name in startup vairable --transaction-log-use-replicator
+#
+
+# Truncate the log file to reset for the next test
+--source ../plugin/transaction_log/tests/t/truncate_log.inc
+
+# Query the DATA_DICTIONARY views and ensure no transaction log
+# was de-activated because of bad replicator name
+
+SELECT * FROM DATA_DICTIONARY.PLUGINS
+WHERE DATA_DICTIONARY.PLUGINS.PLUGIN_NAME LIKE 'Transaction%';
+
+# Truncate the log file to reset for the next test
+--source ../plugin/transaction_log/tests/t/truncate_log.inc

=== modified file 'plugin/transaction_log/tests/t/blob-master.opt'
--- plugin/transaction_log/tests/t/blob-master.opt	2009-11-06 15:22:29 +0000
+++ plugin/transaction_log/tests/t/blob-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/create_select-master.opt'
--- plugin/transaction_log/tests/t/create_select-master.opt	2009-11-10 03:26:40 +0000
+++ plugin/transaction_log/tests/t/create_select-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/create_table-master.opt'
--- plugin/transaction_log/tests/t/create_table-master.opt	2010-02-27 23:47:33 +0000
+++ plugin/transaction_log/tests/t/create_table-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/database-master.opt'
--- plugin/transaction_log/tests/t/database-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/database-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/ddl_transaction_id-master.opt'
--- plugin/transaction_log/tests/t/ddl_transaction_id-master.opt	2010-04-01 16:41:45 +0000
+++ plugin/transaction_log/tests/t/ddl_transaction_id-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/delete-master.opt'
--- plugin/transaction_log/tests/t/delete-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/delete-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/filtered_replicator-master.opt'
--- plugin/transaction_log/tests/t/filtered_replicator-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/filtered_replicator-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---filtered-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --transaction-log-use-replicator=filtered --scheduler=multi_thread --filtered-replicator-filteredschemas=notest

=== modified file 'plugin/transaction_log/tests/t/information_schema-master.opt'
--- plugin/transaction_log/tests/t/information_schema-master.opt	2009-11-09 15:29:23 +0000
+++ plugin/transaction_log/tests/t/information_schema-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/insert-master.opt'
--- plugin/transaction_log/tests/t/insert-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/insert-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/insert_multi-master.opt'
--- plugin/transaction_log/tests/t/insert_multi-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/insert_multi-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/insert_on_duplicate_update-master.opt'
--- plugin/transaction_log/tests/t/insert_on_duplicate_update-master.opt	2009-10-23 16:30:06 +0000
+++ plugin/transaction_log/tests/t/insert_on_duplicate_update-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/insert_select-master.opt'
--- plugin/transaction_log/tests/t/insert_select-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/insert_select-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/multi_column_primary_key-master.opt'
--- plugin/transaction_log/tests/t/multi_column_primary_key-master.opt	2010-02-25 20:20:08 +0000
+++ plugin/transaction_log/tests/t/multi_column_primary_key-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/no_modification-master.opt'
--- plugin/transaction_log/tests/t/no_modification-master.opt	2009-10-29 18:58:54 +0000
+++ plugin/transaction_log/tests/t/no_modification-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/no_primary_key-master.opt'
--- plugin/transaction_log/tests/t/no_primary_key-master.opt	2009-12-11 21:21:33 +0000
+++ plugin/transaction_log/tests/t/no_primary_key-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/rand-master.opt'
--- plugin/transaction_log/tests/t/rand-master.opt	2009-11-10 03:26:40 +0000
+++ plugin/transaction_log/tests/t/rand-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/rename-master.opt'
--- plugin/transaction_log/tests/t/rename-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/rename-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/replace-master.opt'
--- plugin/transaction_log/tests/t/replace-master.opt	2009-10-18 15:31:51 +0000
+++ plugin/transaction_log/tests/t/replace-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/rollback-master.opt'
--- plugin/transaction_log/tests/t/rollback-master.opt	2009-12-04 16:59:27 +0000
+++ plugin/transaction_log/tests/t/rollback-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/schema-master.opt'
--- plugin/transaction_log/tests/t/schema-master.opt	2010-02-25 22:59:56 +0000
+++ plugin/transaction_log/tests/t/schema-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/select_for_update-master.opt'
--- plugin/transaction_log/tests/t/select_for_update-master.opt	2009-12-07 03:59:58 +0000
+++ plugin/transaction_log/tests/t/select_for_update-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/slap-master.opt'
--- plugin/transaction_log/tests/t/slap-master.opt	2010-03-05 04:44:58 +0000
+++ plugin/transaction_log/tests/t/slap-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/temp_tables-master.opt'
--- plugin/transaction_log/tests/t/temp_tables-master.opt	2009-10-16 21:34:21 +0000
+++ plugin/transaction_log/tests/t/temp_tables-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/truncate-master.opt'
--- plugin/transaction_log/tests/t/truncate-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/truncate-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/truncate_log-master.opt'
--- plugin/transaction_log/tests/t/truncate_log-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/truncate_log-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/udf_print_transaction_message-master.opt'
--- plugin/transaction_log/tests/t/udf_print_transaction_message-master.opt	2009-11-16 22:00:02 +0000
+++ plugin/transaction_log/tests/t/udf_print_transaction_message-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/update-master.opt'
--- plugin/transaction_log/tests/t/update-master.opt	2009-10-07 23:59:47 +0000
+++ plugin/transaction_log/tests/t/update-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --scheduler=multi_thread
+--transaction-log-enable --scheduler=multi_thread

=== modified file 'plugin/transaction_log/tests/t/variables-master.opt'
--- plugin/transaction_log/tests/t/variables-master.opt	2010-03-27 18:51:59 +0000
+++ plugin/transaction_log/tests/t/variables-master.opt	2010-04-05 16:06:01 +0000
@@ -1,1 +1,1 @@
---default-replicator-enable --transaction-log-enable --transaction-log-sync-method=1 --scheduler=multi_thread
+--transaction-log-enable --transaction-log-sync-method=1 --scheduler=multi_thread

